# vim: set ts=4 sw=4 et:
#
# spec file for package stunnel (Version 4.34)
#


Name:           stunnel
BuildRequires:  openssl openssl-devel zlib-devel
%if 0%{?suse_version:1}
BuildRequires:  tcpd-devel
%else
BuildRequires:  gcc-c++ tcp_wrappers
%endif
Summary:        Universal SSL Tunnel
License:        GNU Library General Public License v. 2.0 and 2.1 (LGPL)
Version:        4.36
Release:        0.pm.1.1
Group:          Productivity/Networking/Security
URL:            http://www.stunnel.org/
PreReq:         /usr/sbin/useradd fileutils textutils %insserv_prereq %fillup_prereq
Recommends:     logrotate
Source0:        ftp://ftp.stunnel.org/stunnel/stunnel-%{version}.tar.gz
Source1:        %{name}.conf
Source2:        %{name}.README
Source3:        sysconfig.syslog-%{name}
Source4:        %{name}.rc
Source5:        %{name}.logrotate
Source100:      %{name}.changes
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The stunnel program is designed to work as an SSL encryption wrapper
between a remote client and the local (inetd-startable) or remote
server. The concept is that by having non-SSL aware daemons running on
your system, you can easily set them to communicate with clients over a
secure SSL channel. Stunnel can be used to add SSL functionality to
commonly used inetd daemons, such as POP-2, POP-3, and IMAP servers,
without any changes to the program code.




Author
------
    Michal Trojnara  <Michal.Trojnara@mirt.net>

%prep
%setup -q

%build
#autoreconf -fi
sed -i 's/-m 1770 -g nogroup//g' tools/Makefile.in
fPIE="-fPIE"
pie="-pie"
export CFLAGS="$RPM_OPT_FLAGS $fPIE"
%configure \
    --enable-ipv6 \
    --enable-libwrap \
    --localstatedir="%{_var}"

yes . | %__make LDADD="$pie -Wl,-z,defs,-z,relro"

%install
mkdir -p $RPM_BUILD_ROOT/%{_sbindir}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}/{etc,dev,bin,sbin,%_lib,var/run}
mkdir -p $RPM_BUILD_ROOT/var/lib/%{name}
mkdir -p $RPM_BUILD_ROOT/etc/init.d/
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d/
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
make \
    confdir=%{_sysconfdir}/%{name} \
    sbindir=%{_sbindir} \
    libdir=%{_libdir} \
    mandir=%{_mandir} \
    docdir=%{_docdir}/%{name} \
    DESTDIR=$RPM_BUILD_ROOT \
    install
cp -p %{S:1} tools/%{name}.conf-sample
cp -p %{S:2} README.openSUSE
cp -p %{S:3} $RPM_BUILD_ROOT/var/adm/fillup-templates/
install -m 744 $RPM_SOURCE_DIR/%{name}.rc $RPM_BUILD_ROOT/etc/init.d/%{name}
install -m 644 %{SOURCE5} $RPM_BUILD_ROOT/etc/logrotate.d/%{name}
ln -s ../../etc/init.d/%{name} $RPM_BUILD_ROOT/usr/sbin/rc%{name}
ln -s %{name}3 $RPM_BUILD_ROOT/usr/sbin/%{name}3_wrapper
mv $RPM_BUILD_ROOT/%{_bindir}/* $RPM_BUILD_ROOT/%{_sbindir}
rm $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/%{name}.pem
rm $RPM_BUILD_ROOT/%{_sysconfdir}/%{name}/%{name}.conf-sample
rm -rf $RPM_BUILD_ROOT/usr/share/doc/%{name}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%pre
system_user=-r
/usr/sbin/useradd $system_user -g nogroup -s /bin/false -c "Daemon user for %{name} (universal SSL tunnel)" \
 -d /var/lib/%{name} %{name} 2> /dev/null ||:

%post
/sbin/ldconfig 
%{fillup_and_insserv -f}
%{fillup_only -ans syslog %{name}}
if ! test -s etc/%{name}/%{name}.conf; then 
    cp -p usr/share/doc/packages/%{name}/%{name}.conf-sample etc/%{name}/%{name}.conf 
    echo copying default config file to /etc/%{name}/%{name}.conf
fi
# first installation? 
if [ ${FIRST_ARG:-0} = 1 ]; then
if ! test -f etc/%{name}/%{name}.pem; then
    cat usr/share/doc/packages/%{name}/README.openSUSE
fi
fi

%preun
%stop_on_removal %{name}

%postun
/sbin/ldconfig
%restart_on_update %{name}

%files
%defattr(-, root, root)
%doc AUTHORS BUGS COPYING COPYRIGHT.GPL CREDITS ChangeLog INSTALL NEWS PORTS README TODO
%doc README.openSUSE
%doc doc/%{name}.html 
%doc doc/%{name}.*.html 
%doc doc/en/*
%doc doc/pl
%doc tools/%{name}.cnf
%doc tools/%{name}.conf-sample
%{_sbindir}/*
%{_libdir}/%{name}
%{_mandir}/man8/*
%dir %attr(700,root,root) %{_sysconfdir}/%{name}
%dir %attr(755,root,root) 	/var/lib/%{name}
%dir %attr(755,root,root) 	/var/lib/%{name}/bin
%dir %attr(755,root,root) 	/var/lib/%{name}/etc
%dir %attr(755,root,root) 	/var/lib/%{name}/dev
%dir %attr(755,root,root) 	/var/lib/%{name}/%_lib
%dir %attr(755,root,root) 	/var/lib/%{name}/sbin
%dir %attr(755,root,root) 	/var/lib/%{name}/var
%dir %attr(755,%{name},root) 	/var/lib/%{name}/var/run
/var/adm/fillup-templates/sysconfig.syslog-%{name}
%config /etc/init.d/*
%config %{_sysconfdir}/logrotate.d/%{name}

%changelog
* Mon Sep 27 2010 packman@links2linux.de - 4.34
- updated to 4.34
  * New features
    Updated automake to version 1.11.1
    Updated libtool to version 2.2.6b
    Added ECC support with a new service-level "curve" option.
    DH support is now enabled by default.
    Added support for OpenSSL builds with some algorithms disabled.
    ./configure modified to support cross-compilation.
  Sample stunnel.init updated based on Debian init script.
  * Bugfixes
    Implemented fixes in user interface to enter engine PIN.
    Fixed a transfer() loop issue on socket errors.
    Fixed missing WIN32 taskbar icon while displaying a global option error.
* Tue Jul 20 2010 packman@links2linux.de - 4.33
- fixed logrotate-script
* Thu Apr  8 2010 packman@links2linux.de - 4.33
- updated to 4.33
  * New features
    Win32 DLLs for OpenSSL 1.0.0.
    This library requires to c_rehash CApath/CRLpath directories on upgrade.
    Win32 DLLs for zlib 1.2.4.
    Experimental support for local mode on WIN32 platform.
    Try "exec = c:\windows\system32\cmd.exe".
  * Bugfixes
    Inetd mode fixed
- added %%%%insserv_cleanup to %%%%postun
- fixed use of undefined macro in %%%%post
* Sat Apr  3 2010 packman@links2linux.de - 4.32
- package moved to packman
* Sat Mar 27 2010 packman@links2linux.de - 4.32
- updated to 4.32
  * New features
    New service-level "libwrap" option for run-time control whether
    /etc/hosts.allow and /etc/hosts.deny are used for access control.
    Disabling libwrap significantly increases performance of stunnel.
    Win32 DLLs for OpenSSL 0.9.8m.
  * Bugfixes
    Fixed a transfer() loop issue with SSLv2 connections.
    Fixed a "setsockopt IP_TRANSPARENT" warning with "local" option.
    Logging subsystem bugfixes and cleanup.
    Installer bugfixes for Vista and later versions of Windows.
    FIPS mode can be enabled/disabled at runtime.
* Tue Feb  9 2010 packman@links2linux.de - 4.31
- updated to 4.31
  * New features
    Log file reopen on USR1 signal was added.
    Graceful configuration reload with HUP signal on Unix
    and with GUI on Windows.
  * Bugfixes
    Some regression issues introduced in 4.30 were fixed.
- spec cleanup
- fixed some warnings of rpmlintrc
* Thu Dec 24 2009 packman@links2linux.de - 4.29
- updated to version 4.29
- added logrotate-script
